FeatureFlagHelper class

Helper containing the associative map with feature flags and their string values. Reflects the official list of Meet Hour SDK 2.11.0 feature flags

Constructors

FeatureFlagHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

featureFlags ↔ Map<FeatureFlagEnum, String>
getter/setter pair