ContactsType class

Constructors

ContactsType({required int exclude_hosts, required int limit, required int page})

Properties

exclude_hosts ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int
getter/setter pair
page ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited